@@ -45,10 +45,11 @@
 #' \code{gen.enroll.time="uniform"}. Exponential distribution is used when
 #' \code{gen.enroll.time="exponential"}. The default
 #' value is \code{gen.enroll.time="uniform"}.
-#' @param n.earlystop the early stopping parameter. If the number of patients
-#' treated at the current dose reaches \code{n.earlystop},stop the trial and
-#' select the optimal dose (OD) based on the observed data.The default value is
-#' \code{n.earlystop=6}.
+#' @param n.elimination a minimum sample size for dose elimination. If the number
+#' of patients treated at the current dose reaches \code{n.elimination} and meet 
+#' elimination dose level criteria, eliminate current dose level and higher doses 
+#' when meet toxicity criteria and eliminate current dose level when meet efficacy
+#' criteria. The default value is \code{n.elimination=6}.
 #' @param stopping.npts Early study termination criteria for the number of
 #' patients in the dose-escalation and backfill cohorts. If the number of
 #' patients at the current dose reaches this criteria and the same dose level
@@ -112,6 +113,10 @@
 #' level}
 #' \item{n.bpatient}{Average number of back filled patients who were treated
 #' at each dose level}
+#' \item{n.tox.patient}{Average number of patients who experienced toxicity at 
+#' each dose level}
+#' \item{n.eff.patient}{Average number of patients who experienced efficacy at 
+#' each dose level}
 #' \item{prop.select}{Percentage of times that each dose level was selected as
 #' optimal biological dose.}
 #' \item{prop.stop}{Percentage of times that the study was terminated.}
@@ -143,7 +148,7 @@
 #' effprob=effprob,n.dose=5,startdose=1,ncohort=10,cohortsize=3,
 #' pT.saf=0.6 * target_T,pT.tox = 1.4 * target_T,pE.saf = 0.6 * target_E,
 #' alpha.T1=0.5,alpha.E1=0.5,tau.T=1,tau.E=1,te.corr=0.2,
-#' gen.event.time="weibull",accrual=3,gen.enroll.time="uniform",n.earlystop=6,
+#' gen.event.time="weibull",accrual=3,gen.enroll.time="uniform",n.elimination=6,
 #' stopping.npts=12,suspend=0,stopping.prob.T=0.95,stopping.prob.E=0.90,
 #' ppsi01=0,ppsi00=40,ppsi11=60,ppsi10=100,n.sim=2,seed.sim=100)
 #'
@@ -155,7 +160,7 @@
 get.oc.backboinet <- function (target_T=0.3, toxprob,target_E=0.25,effprob,n.dose,startdose,ncohort,cohortsize,
                                pT.saf=0.6 * target_T,pT.tox = 1.4 * target_T,pE.saf = 0.6 * target_E,
                                alpha.T1=0.5,alpha.E1=0.5,tau.T,tau.E,te.corr=0.2,gen.event.time="weibull",
-                               accrual,gen.enroll.time="uniform",n.earlystop=6,stopping.npts=12,
+                               accrual,gen.enroll.time="uniform",n.elimination=6,stopping.npts=12,
                                suspend=0,stopping.prob.T=0.95,stopping.prob.E=0.90,ppsi01=0,ppsi00=40,ppsi11=60,
                                ppsi10=100,n.sim=1000,seed.sim=100){
 
@@ -709,11 +714,11 @@ for(simu in 1:n.sim){
 
       ###determine which dose level should be eliminated
 
-      if(length(which((tterm<(1-stopping.prob.T))&(nvector>=n.earlystop)))>0){
-        elimi_tox[(min(which((tterm<(1-stopping.prob.T))&(nvector>=n.earlystop)))):n.dose]<-1
+      if(length(which((tterm<(1-stopping.prob.T))&(nvector>=n.elimination)))>0){
+        elimi_tox[(min(which((tterm<(1-stopping.prob.T))&(nvector>=n.elimination)))):n.dose]<-1
       }
-      if(length(which((eterm<(1-stopping.prob.E))&(nvector>=n.earlystop)))>0){
-        elimi_eff[which((eterm<(1-stopping.prob.E))&(nvector>=n.earlystop))]<-1
+      if(length(which((eterm<(1-stopping.prob.E))&(nvector>=n.elimination)))>0){
+        elimi_eff[which((eterm<(1-stopping.prob.E))&(nvector>=n.elimination))]<-1
       }
 
       elimi<-elimi_tox+elimi_eff
@@ -837,6 +842,11 @@ for(simu in 1:n.sim){
         n.bpatient <- round(apply(backfillcount,2,mean),digits=2)
         names(n.bpatient) <- dose
 
+        n.tox.patient <- round(apply(toxicity,2,mean),digits=2)
+        names(n.tox.patient) <- dose
+ 
+        n.eff.patient <- round(apply(efficacy,2,mean),digits=2)
+        names(n.eff.patient) <- dose       
 
         duration  <- round(mean(data.dur),digits=1)
         names(duration) <- "Trial duration"
@@ -909,6 +919,8 @@ for(simu in 1:n.sim){
                        accrual      = accrual,
                        n.patient    = n.patient,
                        n.bpatient   = n.bpatient,
+                       n.tox.patient= n.tox.patient,
+                       n.eff.patient= n.eff.patient,
                        prop.select  = prop.select,
                        prop.stop    = prop.stop,
                        duration     = duration,
